@@ -42,8 +42,6 @@ step 2: apply SURF.
 /*
 step 3: extract a readable cookie from the SURF output.
 */
-  for (i = 0;i < 10;++i) {
-    hash[i + i] = 'a' + (out[i] >> 4);
-    hash[i + i + 1] = 'a' + (out[i] & 15);
-  }
+  for (i = 0;i < 20;++i) 
+    hash[i] = 'a' + (out[i] & 15);
 }
